<!DOCTYPE kpartgui>
<kpartplugin name="khtmlsettingsplugin" library="libkhtmlsettingsplugin" version="3">
<MenuBar>
 <Menu name="tools"><Text>&amp;Tools</Text>
  <Action name="action menu"/>
 </Menu>
</MenuBar>
<ToolBar name="extraToolBar"><text>Extra Toolbar</text>
  <Action name="action menu"/>
</ToolBar>
</kpartplugin>
