<!DOCTYPE kpartgui>
<kpartgui name="atlanticdesigner" version="2">
<MenuBar>
  <Menu name="file">
    <Action name="boardinfo" />
	<Action name="groupeditor" />
  </Menu>
  <Menu name="edit">
    <Action name="smaller" />
    <Action name="larger" />
  </Menu>
  <Menu name="go_web">
    <Action name="estate_num" />
    <Separator />
    <Action name="up" />
    <Action name="down" />
    <Action name="left" />
    <Action name="right" />
  </Menu>
</MenuBar>
<ToolBar name="mainToolBar">
  <Action name="estate_num" />
</ToolBar>
</kpartgui>
