<!DOCTYPE kpartgui>
<kpartgui name="ksig">

<MenuBar>
	<Menu name="file"><text>&amp;File</text>
		<Action name="remove"/>
	</Menu>
	<Menu name="edit"><text>&amp;Edit</text>
		<Action name="clear"/>
	</Menu>
	<Menu name="settings"><text>&amp;Settings</text>
		<Action name="editHeader"/>
		<Action name="editFooter"/>
	</Menu>
</MenuBar>

<ToolBar name="mainToolBar"><text>Main Toolbar</text>
	<Action name="remove"/>
</ToolBar>

</kpartgui>
