( cd opt/kde/lib/kde3 ; rm -rf libvimpart.so )
( cd opt/kde/lib/kde3 ; ln -sf libvimpart.so.0.0.0 libvimpart.so )
( cd opt/kde/lib/kde3 ; rm -rf libvimpart.so.0 )
( cd opt/kde/lib/kde3 ; ln -sf libvimpart.so.0.0.0 libvimpart.so.0 )
( cd opt/kde/lib ; rm -rf libxvim.so )
( cd opt/kde/lib ; ln -sf libxvim.so.0.0.0 libxvim.so )
( cd opt/kde/lib ; rm -rf libxvim.so.0 )
( cd opt/kde/lib ; ln -sf libxvim.so.0.0.0 libxvim.so.0 )
( cd opt/kde/share/doc/HTML/en/kate-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/kicker-applets ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/babel ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/babel ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/konq-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/crashes ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/crashes ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/dirfilter ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/dirfilter ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/domtreeviewer ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/domtreeviewer ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/fsview ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/fsview ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/imgallery ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/imgallery ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/khtmlsettings ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/khtmlsettings ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/kuick ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/kuick ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/mediaplayer ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/mediaplayer ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/smbmounter ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/smbmounter ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/uachanger ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/uachanger ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/validators ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/validators ; ln -sf /opt/kde/share/doc/HTML/en/common common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/webarchiver ; rm -rf common )
( cd opt/kde/share/doc/HTML/en/konq-plugins/webarchiver ; ln -sf /opt/kde/share/doc/HTML/en/common common )
