<!DOCTYPE kpartplugin>
<kpartplugin name="UserAgentChanger" library="libuachangerplugin">
<MenuBar>
 <Menu name="tools"><Text>&amp;Tools</Text>
  <Action name="changeuseragent"/>
 </Menu>
</MenuBar>
<ToolBar name="extraToolBar"><text>Extra Toolbar</text>
  <Action name="changeuseragent"/>
</ToolBar>
</kpartplugin>
