<!DOCTYPE kpartplugin>
<kpartplugin name="FSViewPart" library="libfsviewpart" version = "1">
<MenuBar>
 <Menu name="view"><Text>&amp;View</Text>
  <Separator/>
  <Action name="treemap_visdir"/>
  <Action name="treemap_colordir"/>
  <Action name="treemap_areadir"/>
 </Menu>
 <Menu name="help"><text>&amp;Help</text>
  <Action name="help_fsview"/>
 </Menu>
</MenuBar>
</kpartplugin>
