<!DOCTYPE kpartgui> 
	<kpartgui library="libautorefresh" name="autorefresh" version="0.1" > 
	<MenuBar> 
		<Menu name="tools">
			<Text>&amp;Tools</Text> 
			<Action name="autorefresh"/> 
		</Menu> 
	</MenuBar> 
</kpartgui>

