<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="VimView">
<MenuBar>
  <Menu name="file"><text>&amp;File</text>
    <Action name="file_save_as"/>
  </Menu>

  <Menu name="edit"><text>&amp;Edit</text>
    <Action name="edit_select_all"/>
    <Action name="go_goto_line"/>
    <Action name="edit_find"/>
  </Menu>
</MenuBar>

<ToolBar name="mainToolBar"><text>Main Toolbar</text>
	<Action name="file_save"/>
  <Action name="edit_find"/>
</ToolBar>

</kpartgui>
