<!DOCTYPE kpartgui>
<kpartplugin name="katefilelistloader" library="libkatefll_plugin" version="3">
<MenuBar>
<Menu name="file"><Text>&amp;File</Text> 
 <Menu name="filelistloader" group="print_merge"><Text>&amp;Filelist</Text>
    <Action name="file_kfllopen" />
    <Action name="file_kfllsave" />
    <Action name="file_kfllsaveas" />
 </Menu>
</Menu>
</MenuBar>
</kpartplugin>
