<!DOCTYPE kpartplugin>
<kpartplugin library="konq_smbmounterplugin">
<MenuBar>
 <Menu name="tools"><text>&amp;Tools</text>
  <Action name="smbmount"/>
  <Action name="smbumount"/>
 </Menu>
</MenuBar>
</kpartplugin>
