<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="VimPart" version="1">
<MenuBar>
  <Menu name="file"><text>&amp;File</text>
    <Action name="file_save" />
		<Action name="file_save_as"/>
  </Menu>

  <Menu name="edit"><text>&amp;Edit</text>
    <Action name="edit_undo"/>
    <Action name="edit_redo"/>
    <Action name="edit_cut" />
    <Action name="edit_copy" />
    <Action name="edit_paste"/>
    <Action name="edit_select_all"/>
    <Action name="edit_deselect"/>
    <Action name="set_insert"/>
    <Action name="edit_find"/>
    <Action name="edit_replace"/>
    <Action name="go_goto_line"/>
  </Menu>
</MenuBar>

<ToolBar name="mainToolBar"><text>Main Toolbar</text>
  <Action name="file_save" />
  <Action name="file_save_as"/>
  <Action name="edit_undo" />
  <Action name="edit_redo"  />
  <Action name="edit_cut" />
  <Action name="edit_copy" />
  <Action name="edit_paste" />
  <Action name="edit_find" />
</ToolBar>

</kpartgui>
