<!DOCTYPE kpartgui>
<kpartplugin name="katepybrowse" library="libkatepybrowseplugin" version="2">
<MenuBar>
	<Menu name="python"><Text>&amp;Python</Text>
  	<Action name="python_update_pybrowse" />
  </Menu>
</MenuBar>
</kpartplugin>
