<!DOCTYPE kpartgui>
<kpartplugin name="kateinsertcommand" library="libkateinsertcommandplugin" version="2">
<MenuBar>
 <Menu name="tools"><Text>&amp;Tools</Text>
    <Action name="edit_insert_command" />
 </Menu>
</MenuBar>
</kpartplugin>
