<!DOCTYPE kpartgui>
<kpartplugin name="katemodeline" library="libkatemodelineplugin" version="2">
<MenuBar>
	<Menu name="tools"><text>&amp;Tools</text>
		<Action name="edit_apply_modeline" />
	</Menu>
</MenuBar>
</kpartplugin>
