<!DOCTYPE kpartgui>
<kpartgui name="noatunlyrics">
<MenuBar>
  <Menu name="go_web">
    <Action name="go_web_goTo"/>
  </Menu>
  <Menu name="settings">
    <Action name="follow"/>
    <Action name="attach_url"/>
    <Action name="search_provider"/>
  </Menu>
</MenuBar>
<ToolBar name="mainToolBar">
	<Action name="go_back"/>
	<Action name="go_forward"/>
  <Action name="view_redisplay"/>
  <Separator/>
  <Action name="follow"/>
  <Separator/>
  <Action name="attach_url"/>
  <Action name="search_label"/>
  <Action name="search_provider"/>
</ToolBar>
</kpartgui>
